/**
 * Created by jie on 2017/12/19.
 */
var log4js = require('log4js');
var moment=require('moment');
var path = require('path');
var fs = require('fs')

function logFileName(filepath,filename) {
    var dirpath=filepath;
    if(!fs.existsSync(dirpath))
    {
        fs.mkdirSync(dirpath);
    }
    return path.join(filepath , filename );
}

var Filelog = exports.filelog = function (options) {
    log4js.addLayout('json',function () {
       return function (logEvent) {
           var logMsgJson={};
           if(logEvent){
               logMsgJson=JSON.parse( JSON.stringify(logEvent.data[0]));
               logMsgJson.url=logMsgJson.url || '';
               logMsgJson.time= moment().format('YYYY-MM-DD HH:mm:ss');
               logMsgJson.level=logMsgJson.level ||logEvent.level.levelStr.toLowerCase();
               logMsgJson.identifier=logMsgJson.identifier || '';
           }
          return JSON.stringify(logMsgJson);
       }
    });
    if(options){
        var filename=logFileName(options.filepath,'log')
        var pattern=options.datePattern || 'yyyy-MM-dd';
        this.option={
            type:'dateFile',
            pattern: '-'+pattern+'.log',
            alwaysIncludePattern: true,
            filename:filename,
            category:'json-logger',
            layout:{
                type:'json'
            }
        };
    }
    else {
        throw "Parameter incomplete";
    }
    log4js.configure({
        appenders:{
            filelog:this.option
        },
        categories: {
            default: { appenders: ['filelog'], level: 'debug' }
        }
    });
    this.logger = log4js.getLogger('json-logger');
};

//
// ### function logInfo
// #### @message {string} json to log into db
//
Filelog.prototype.logInfo=function(message,callback){
    try{
        var msg_obj={};
        if(message){
            msg_obj=JSON.parse( JSON.stringify(message));
            msg_obj.url=message.url||process.cwd();
        }
        this.logger.info(msg_obj);
        callback(null,{
            msgcode:'200',
            msg:'ok'
        });
    }
    catch (err){
        callback(err,{
            msgcode:'201',
            msg:'fail'
        });
    }
};

//
// ### function logDebug
// #### @message {string} json to log into db
//
Filelog.prototype.logDebug=function(message,callback){
    //console.log("logDebug");
    try{
        var msg_obj={};
        if(message){
            msg_obj=JSON.parse( JSON.stringify(message));
            msg_obj.url=message.url||process.cwd();
        }
        this.logger.debug(msg_obj);
        callback(null,{
            msgcode:'200',
            msg:'ok'
        });
    }
    catch (err){
        callback(err,{
            msgcode:'201',
            msg:'fail'
        });
    }
};

//
// ### function logError
// #### @message {string} json to log into db
//
Filelog.prototype.logError=function(message,callback){
    //console.log("logError");
    try{
        var msg_obj={};
        if(message){
            msg_obj=JSON.parse( JSON.stringify(message));
            msg_obj.url=message.url||process.cwd();
        }
        this.logger.error(msg_obj);
        callback(null,{
            msgcode:'200',
            msg:'ok'
        });
    }
    catch (err){
        callback(err,{
            msgcode:'201',
            msg:'fail'
        });
    }
};

Filelog.prototype.log=function(level,message,callback){
    //console.log("logError");
    try{
        var msg_obj={};
        if(message){
            msg_obj=JSON.parse( JSON.stringify(message));
            msg_obj.url=message.url||process.cwd();
            msg_obj.level=level;
        }
        this.logger.info(msg_obj);
        callback(null,{
            msgcode:'200',
            msg:'ok'
        });
    }
    catch (err){
        callback(err,{
            msgcode:'201',
            msg:'fail'
        });
    }
};




